/* Let FILENAME EMAIL know HTML is coming... */
filename mymail email "mark.jordan@sas.com" subject="This is a test" type="TEXT/HTML";

ods html5 body=mymail style=htmlblue;
options nocenter;
title;
data _null_;
   file print;
   put 'Emailing from SAS is fun!';
   put 'Stay SASy!';
   put 'Mark';
run;
ods html5 close;

ods html5 body=mymail style=htmlblue;
options nocenter;
title;
proc odstext;
   p 'Emailing from SAS is fun!' ;
   p 'Here are a few reasons:' ;
   list;
      item 'SAS types better than I do';
      item 'Everybody loves computer-generated email!';
   end;
   p 'Stay SASy!'; 
   p 'Mark';
run;
ods html5 close;

filename mymail email "mark.jordan@sas.com" subject="US Automobile Stats" type="TEXT/HTML";
ods html5 body=mymail style=journal3;
options nocenter;
title;
proc odstext;
   p 'Here is the information you requested.' ;
   p 'All the best,'; 
   p 'Mark';
run;
  /* Insert query results */
PROC SQL;
title "US Automobile Stats by Make";
   SELECT Make
        , COUNT(distinct Model) 'Models'
        , COUNT(distinct Type) 'Types'
        , Avg((MPG_Highway+MPG_City)/2) 'Overall MPG' format=5.1
        , Avg(Horsepower) 'Average HP' format=5.1
        , Avg(weight)    'Average Weight' format=5.1
      from sashelp.cars
      where origin='USA'
      group by Make
   ;
quit;

proc sql;
title "US SUV Stats by Make";
   SELECT Make
        , COUNT(distinct Model) 'Models'
        , Avg((MPG_Highway+MPG_City)/2) 'Overall MPG' format=5.1
        , Avg(Horsepower) 'Average HP' format=5.1
        , Avg(weight)    'Average Weight' format=5.1
      from sashelp.cars
      where origin='USA' 
        and Type='SUV'
      group by Make, Type
   ;
quit;

proc sql;
title "US Auto Stats by Make and Type";
   SELECT Make
        , Type
        , COUNT(distinct Model) 'Models'
        , Avg((MPG_Highway+MPG_City)/2) 'Overall MPG' format=5.1
        , Avg(Horsepower) 'Average HP' format=5.1
        , Avg(weight)    'Average Weight' format=5.1
      from sashelp.cars
      where origin='USA' 
      group by Make, Type
   ;
quit;
ods html5 close;
 

/* Let's attach the detail report as a PDF instead of in the email body*/
/* First, build the Report.pdf file in the same directory as WORK library */
/* SAS will then delete this PDF along with the WORK library at shutdown  */

ods pdf body="%sysfunc(pathname(work))\Report.pdf" style=Journal3 pdftoc=1;
ods proclabel "Autos by Make";
title "US Automobile Stats by Make";
PROC SQL ;
   SELECT Make
        , COUNT(distinct Model) 'Models'
        , COUNT(distinct Type) 'Types'
        , Avg((MPG_Highway+MPG_City)/2) 'Overall MPG' format=5.1
        , Avg(Horsepower) 'Average HP' format=5.1
        , Avg(weight)    'Average Weight' format=5.1
      from sashelp.cars
      where origin='USA'
      group by Make
   ;
quit;

ods proclabel "SUVs";
title "US SUV Stats by Make";
proc sql;
   SELECT Make
        , COUNT(distinct Model) 'Models'
        , Avg((MPG_Highway+MPG_City)/2) 'Overall MPG' format=5.1
        , Avg(Horsepower) 'Average HP' format=5.1
        , Avg(weight)    'Average Weight' format=5.1
      from sashelp.cars
      where origin='USA' 
        and Type='SUV'
      group by Make, Type
   ;
quit;

ods proclabel "Autos by Make and Type";
title "US Auto Stats by Make and Type";
proc sql;
   SELECT Make
        , Type
        , COUNT(distinct Model) 'Models'
        , Avg((MPG_Highway+MPG_City)/2) 'Overall MPG' format=5.1
        , Avg(Horsepower) 'Average HP' format=5.1
        , Avg(weight)    'Average Weight' format=5.1
      from sashelp.cars
      where origin='USA' 
      group by Make, Type
   ;
quit;
ods pdf close;

/* Modified program - some results in the email body, some in attachment */
/* Set up this email */
filename mymail email "mark.jordan@sas.com" subject="US Automobile Stats" type="TEXT/HTML"
         /* Add the attachment information */ 
         attach="%sysfunc(pathname(work))\Report.pdf";
ods html5 body=mymail style=journal3;
options nocenter;
title;
proc odstext;
   p 'Here is the information you requested.' ;
   p 'All the best,'; 
   p 'Mark';
run;

ods html5 close;
